@@ -18,6 +18,7 @@ import (
 	"github.com/blacktop/ipsw/internal/commands/ent"
 	"github.com/blacktop/ipsw/internal/commands/extract"
 	"github.com/blacktop/ipsw/internal/utils"
+	"github.com/blacktop/ipsw/pkg/aea"
 	"github.com/blacktop/ipsw/pkg/info"
 	"github.com/gin-gonic/gin"
 )
@@ -69,6 +70,13 @@ func getFsFiles(c *gin.Context) {
 		utils.Indent(log.Debug, 2)(fmt.Sprintf("Found extracted %s", dmgPath))
 	}
 
+	if filepath.Ext(dmgPath) == ".aea" {
+		dmgPath, err = aea.Parse(dmgPath, filepath.Dir(dmgPath), nil)
+		if err != nil {
+			c.AbortWithStatusJSON(http.StatusInternalServerError, types.GenericError{Error: fmt.Sprintf("failed to parse AEA encrypted DMG: %v", err)})
+		}
+	}
+
 	// mount filesystem DMG
 	utils.Indent(log.Info, 2)(fmt.Sprintf("Mounting %s", dmgPath))
 	mountPoint, alreadyMounted, err := utils.MountDMG(dmgPath)
