@@ -82,7 +82,7 @@ var MachoCmd = &cobra.Command{
 	Use:     "macho <DSC> <DYLIB>",
 	Aliases: []string{"m"},
 	Short:   "Parse an incache dylib file",
-	Args:    cobra.ExactArgs(2),
+	Args:    cobra.MinimumNArgs(1),
 	ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 1 {
 			return getImages(args[0]), cobra.ShellCompDirectiveDefault
@@ -322,7 +322,7 @@ var MachoCmd = &cobra.Command{
 							return fmt.Errorf("failed to dump swift data: %v", err)
 						}
 					} else {
-						fmt.Println("  - no swift")
+						fmt.Print("  - no swift")
 					}
 					println()
 				}
