@@ -12,6 +12,7 @@ import (
 
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
+	"github.com/blacktop/ipsw/pkg/aea"
 	"github.com/blacktop/ipsw/pkg/info"
 )
 
@@ -98,6 +99,13 @@ func DmgInIPSW(path, typ string) (*Context, error) {
 		}
 	}
 
+	if filepath.Ext(extractedDMG) == ".aea" {
+		extractedDMG, err = aea.Parse(extractedDMG, filepath.Dir(extractedDMG), nil)
+		if err != nil {
+			return nil, fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
+		}
+	}
+
 	mp, am, err := utils.MountDMG(extractedDMG)
 	if err != nil {
 		return nil, fmt.Errorf("failed to mount %s: %v", extractedDMG, err)
